/*
 * @Author: Yujialong
 * @Date: 2021-11-03 14:33:21
 * @LastEditTime: 2021-11-08 19:20:52
 * @LastEditors: Please set LastEditors
 * @Description: 打开koroFileHeader查看配置 进行设置: https://github.com/OBKoro1/koro1FileHeader/wiki/%E9%85%8D%E7%BD%AE
 * @FilePath: \questionnaired:\code\FE_huoran_data\src\store\modules\user.js
 */

import Setting from '@/setting'
import util from '@/libs/util'
import {post,get,del,put} from '@/plugins/requests/index.js'
import api from '@/api'

/**
 * 用户信息
 * */
export default {
    namespaced: true,
    state: {
        avatar: 'https://cube.elemecdn.com/3/7c/3ea6beec64369c2642b92c6726f1epng.png',
        schoolId: '',
        userName: '',
        isManager: false,
        isCustomer: false
    },
    mutations: {
        SET_INFO: (state, info) => {
            if(info.avatar) state.avatar = info.avatar
            if(info.schoolId) state.schoolId = info.schoolId
            if(info.userName) state.userName = info.userName
        },
        SET_AVATAR: (state, avatar) => {
            state.avatar = avatar
        },
        SET_MANAGER: (state, isManager) => {
            state.isManager = isManager
        },
        SET_CUSTOMER: (state, isCustomer) => {
            state.isCustomer = isCustomer
        },
    },
    actions: {
        login({ state,commit }, userInfo) {
            const { account, password, code, random, distinguish } = userInfo
            return new Promise((resolve, reject) => {
                post(api.logins,{
                    account,
                    password,
                    code,
                    random,
                    distinguish,
                    type: 2, // 平台端区分：0->教师端 1->学生端 2->无端
                    platform: Setting.platformId, // 所属平台id(1.职站 2.数据平台 3.中台)
                }).then(res => {
                    if(res.status == 200){
                        util.local.set(Setting.tokenKey,res.data.token,43200000)
                        util.successMsg('登录成功')
                        get(api.isClient).then(res => {
                            commit('SET_CUSTOMER',res.customer)
                            const userName = res.customerName
                            userName && commit('SET_INFO', {
                                userName
                            })
                        }).catch(res => {})
                        post(api.getSchoolIdByToken).then(res => {
                            commit('SET_INFO',res)
                        }).catch(res => {})
                        setTimeout(() => {
                            // 登录次数+1
                            post(api.saveRecord,{
                                type: 3,
                            }).then(res => {}).catch(res => {})
                        },3000)
                        resolve()
                    }else{
                        util.errorMsg(res.message)
                        reject(res)
                    }
                }).catch(error => {
                    reject(error)
                })
            })
        },
        logout({ commit, state, dispatch }) {
            return new Promise((resolve, reject) => {
                util.local.remove(Setting.storeKey)
                util.local.remove(Setting.tokenKey)
                location.reload()
                resolve()
            })
        },
        setAvatar({ state,commit },avatar) {
            commit('SET_AVATAR',avatar)
        },
        setInfo({ state,commit },info) {
            commit('SET_INFO',info)
        },
        setManager({ state,commit },isManager) {
            commit('SET_MANAGER',isManager)
        },
        setCustomer({ state,commit },isCustomer) {
            commit('SET_CUSTOMER',isCustomer)
        },
    }
}